# @Author: BingWu Yang <detailyang>
# @Date:   2016-03-30T20:49:47+08:00
# @Email:  detailyang@gmail.com
# @Last modified by:   detailyang
# @Last modified time: 2016-03-30T20:56:55+08:00
# @License: The MIT License (MIT)


from esl.eslyacc import parse
from eslast import *

__version__ = '0.1.0'
