
# parsetab.py
# This file is automatically generated. Do not edit.
_tabversion = '3.8'

_lr_method = 'LALR'

_lr_signature = '26C673E7BBE145DDDB6A7C8BE02FCE0C'
    
_lr_action_items = {'BODY':([3,4,5,6,7,8,9,10,],[4,-10,-5,-9,4,-8,-7,-6,]),'URL':([0,],[1,]),'QUERYSTRING':([3,4,5,6,7,8,9,10,],[6,-10,-5,-9,6,-8,-7,-6,]),'HEADER':([3,4,5,6,7,8,9,10,],[8,-10,-5,-9,8,-8,-7,-6,]),'METHOD':([1,],[3,]),'$end':([1,2,3,4,5,6,7,8,9,10,],[-1,0,-2,-10,-5,-9,-3,-8,-7,-6,]),}

_lr_action = {}
for _k, _v in _lr_action_items.items():
   for _x,_y in zip(_v[0],_v[1]):
      if not _x in _lr_action:  _lr_action[_x] = {}
      _lr_action[_x][_k] = _y
del _lr_action_items

_lr_goto_items = {'request':([0,],[2,]),'OPTIONS':([3,],[7,]),'empty':([3,7,],[9,9,]),'OPTION':([3,7,],[5,10,]),}

_lr_goto = {}
for _k, _v in _lr_goto_items.items():
   for _x, _y in zip(_v[0], _v[1]):
       if not _x in _lr_goto: _lr_goto[_x] = {}
       _lr_goto[_x][_k] = _y
del _lr_goto_items
_lr_productions = [
  ("S' -> request","S'",1,None,None,None),
  ('request -> URL','request',1,'p_request','eslyacc.py',27),
  ('request -> URL METHOD','request',2,'p_request','eslyacc.py',28),
  ('request -> URL METHOD OPTIONS','request',3,'p_request','eslyacc.py',29),
  ('OPTIONS -> <empty>','OPTIONS',0,'p_options','eslyacc.py',39),
  ('OPTIONS -> OPTION','OPTIONS',1,'p_options','eslyacc.py',40),
  ('OPTIONS -> OPTIONS OPTION','OPTIONS',2,'p_options','eslyacc.py',41),
  ('OPTION -> empty','OPTION',1,'p_option_empty','eslyacc.py',49),
  ('OPTION -> HEADER','OPTION',1,'p_option_header','eslyacc.py',53),
  ('OPTION -> QUERYSTRING','OPTION',1,'p_option_querystring','eslyacc.py',57),
  ('OPTION -> BODY','OPTION',1,'p_option_body','eslyacc.py',61),
  ('empty -> <empty>','empty',0,'p_empty','eslyacc.py',65),
]
